@@ -10,7 +10,7 @@
 #include "eog-image-save-info.h"
 #include "eog-job.h"
 
-#if HAVE_LCMS
+#ifdef HAVE_LCMS
 #include <lcms.h>
 #endif
 
@@ -120,7 +120,7 @@ GnomeVFSURI*        eog_image_get_uri                         (EogImage *img);
 gchar*              eog_image_get_uri_for_display             (EogImage *img);
 gboolean            eog_image_has_metadata                    (EogImage *img);
 
-#if HAVE_LCMS
+#ifdef HAVE_LCMS
 cmsHPROFILE eog_image_get_profile (EogImage *img);
 void eog_image_apply_display_profile (EogImage *img, cmsHPROFILE profile);
 #endif
